@@ -404,6 +404,15 @@ set_command_line_wait (GeditApp *app,
 	                        (GDestroyNotify)g_object_unref);
 }
 
+static void
+set_command_line_wait_doc (GeditDocument *doc,
+			   GeditApp      *app)
+{
+	GeditTab *tab = gedit_tab_get_from_document (doc);
+
+	set_command_line_wait (app, tab);
+}
+
 static void
 open_files (GApplication            *application,
 	    gboolean                 new_window,
@@ -474,7 +483,7 @@ open_files (GApplication            *application,
 
 		if (command_line)
 		{
-			g_slist_foreach (loaded, (GFunc)set_command_line_wait, NULL);
+			g_slist_foreach (loaded, (GFunc)set_command_line_wait_doc, GEDIT_APP (application));
 		}
 		g_slist_free (loaded);
 	}
@@ -1369,13 +1378,17 @@ load_print_settings (GeditApp *app)
 	filename = get_print_settings_file ();
 
 	priv->print_settings = gtk_print_settings_new_from_file (filename, &error);
-	if (error)
+	if (error != NULL)
 	{
-		/* Ignore file not found error */
-		if (error->domain != G_FILE_ERROR ||
-		    error->code != G_FILE_ERROR_NOENT)
+		/* - Ignore file not found error.
+		 * - Ignore empty file error, i.e. group not found. This happens
+		 *   when we click on cancel in the print dialog, when using the
+		 *   printing for the first time in gedit.
+		 */
+		if (!g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT) &&
+		    !g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_GROUP_NOT_FOUND))
 		{
-			g_warning ("%s", error->message);
+			g_warning ("Load print settings error: %s", error->message);
 		}
 
 		g_error_free (error);
@@ -1807,12 +1820,7 @@ _gedit_app_set_default_page_setup (GeditApp     *app,
 
 	priv = gedit_app_get_instance_private (app);
 
-	if (priv->page_setup != NULL)
-	{
-		g_object_unref (priv->page_setup);
-	}
-
-	priv->page_setup = g_object_ref (page_setup);
+	g_set_object (&priv->page_setup, page_setup);
 }
 
 /* Returns a copy */
