@@ -21,7 +21,6 @@
  * Boston, MA  02110-1301  USA
  */
 
-
 #ifndef __GEDIT_SETTINGS_H__
 #define __GEDIT_SETTINGS_H__
 
@@ -31,31 +30,9 @@
 
 G_BEGIN_DECLS
 
-#define GEDIT_TYPE_SETTINGS		(gedit_settings_get_type ())
-#define GEDIT_SETTINGS(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), GEDIT_TYPE_SETTINGS, GeditSettings))
-#define GEDIT_SETTINGS_CONST(obj)	(G_TYPE_CHECK_INSTANCE_CAST ((obj), GEDIT_TYPE_SETTINGS, GeditSettings const))
-#define GEDIT_SETTINGS_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), GEDIT_TYPE_SETTINGS, GeditSettingsClass))
-#define GEDIT_IS_SETTINGS(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEDIT_TYPE_SETTINGS))
-#define GEDIT_IS_SETTINGS_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GEDIT_TYPE_SETTINGS))
-#define GEDIT_SETTINGS_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), GEDIT_TYPE_SETTINGS, GeditSettingsClass))
+#define GEDIT_TYPE_SETTINGS (gedit_settings_get_type ())
 
-typedef struct _GeditSettings		GeditSettings;
-typedef struct _GeditSettingsClass	GeditSettingsClass;
-typedef struct _GeditSettingsPrivate	GeditSettingsPrivate;
-
-struct _GeditSettings
-{
-	GObject parent;
-
-	GeditSettingsPrivate *priv;
-};
-
-struct _GeditSettingsClass
-{
-	GObjectClass parent_class;
-};
-
-GType			 gedit_settings_get_type			(void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (GeditSettings, gedit_settings, GEDIT, SETTINGS, GObject)
 
 GObject			*gedit_settings_new				(void);
 
@@ -101,6 +78,7 @@ void			 gedit_settings_set_list			(GSettings     *settings,
 #define GEDIT_SETTINGS_STATUSBAR_VISIBLE		"statusbar-visible"
 #define GEDIT_SETTINGS_SIDE_PANEL_VISIBLE		"side-panel-visible"
 #define GEDIT_SETTINGS_BOTTOM_PANEL_VISIBLE		"bottom-panel-visible"
+#define GEDIT_SETTINGS_MINIMAP_VISIBLE			"minimap-visible"
 #define GEDIT_SETTINGS_MAX_RECENTS			"max-recents"
 #define GEDIT_SETTINGS_PRINT_SYNTAX_HIGHLIGHTING	"print-syntax-highlighting"
 #define GEDIT_SETTINGS_PRINT_HEADER			"print-header"
@@ -109,6 +87,10 @@ void			 gedit_settings_set_list			(GSettings     *settings,
 #define GEDIT_SETTINGS_PRINT_FONT_BODY_PANGO		"print-font-body-pango"
 #define GEDIT_SETTINGS_PRINT_FONT_HEADER_PANGO		"print-font-header-pango"
 #define GEDIT_SETTINGS_PRINT_FONT_NUMBERS_PANGO		"print-font-numbers-pango"
+#define GEDIT_SETTINGS_PRINT_MARGIN_LEFT		"margin-left"
+#define GEDIT_SETTINGS_PRINT_MARGIN_TOP			"margin-top"
+#define GEDIT_SETTINGS_PRINT_MARGIN_RIGHT		"margin-right"
+#define GEDIT_SETTINGS_PRINT_MARGIN_BOTTOM		"margin-bottom"
 #define GEDIT_SETTINGS_CANDIDATE_ENCODINGS		"candidate-encodings"
 #define GEDIT_SETTINGS_ACTIVE_PLUGINS			"active-plugins"
 #define GEDIT_SETTINGS_ENSURE_TRAILING_NEWLINE		"ensure-trailing-newline"
