@@ -18,20 +18,9 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "gedit-tab-label.h"
-
-#include <glib/gi18n.h>
-#include <gtk/gtk.h>
-
-#include "gedit-small-button.h"
-#include "gedit-tab.h"
 #include "gedit-tab-private.h"
 
-/* Signals */
 enum
 {
 	CLOSE_CLICKED,
@@ -50,24 +39,16 @@ struct _GeditTabLabel
 
 	GeditTab *tab;
 
-	GtkWidget *close_button;
 	GtkWidget *spinner;
 	GtkWidget *icon;
 	GtkWidget *label;
-
-	gboolean close_button_sensitive;
+	GtkWidget *close_button;
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GeditTabLabel, gedit_tab_label, GTK_TYPE_BOX)
 
-static void
-gedit_tab_label_finalize (GObject *object)
-{
-	G_OBJECT_CLASS (gedit_tab_label_parent_class)->finalize (object);
-}
-
 static void
 gedit_tab_label_set_property (GObject      *object,
 			      guint         prop_id,
@@ -79,6 +60,7 @@ gedit_tab_label_set_property (GObject      *object,
 	switch (prop_id)
 	{
 		case PROP_TAB:
+			g_return_if_fail (tab_label->tab == NULL);
 			tab_label->tab = GEDIT_TAB (g_value_get_object (value));
 			break;
 
@@ -116,8 +98,8 @@ close_button_clicked_cb (GtkWidget     *widget,
 }
 
 static void
-sync_tip (GeditTab *tab,
-	  GeditTabLabel *tab_label)
+sync_tooltip (GeditTab      *tab,
+	      GeditTabLabel *tab_label)
 {
 	gchar *str;
 
@@ -143,7 +125,7 @@ sync_name (GeditTab      *tab,
 	gtk_label_set_text (GTK_LABEL (tab_label->label), str);
 	g_free (str);
 
-	sync_tip (tab, tab_label);
+	sync_tooltip (tab, tab_label);
 }
 
 static void
@@ -152,12 +134,10 @@ update_close_button_sensitivity (GeditTabLabel *tab_label)
 	GeditTabState state = gedit_tab_get_state (tab_label->tab);
 
 	gtk_widget_set_sensitive (tab_label->close_button,
-				  tab_label->close_button_sensitive &&
 				  (state != GEDIT_TAB_STATE_CLOSING) &&
 				  (state != GEDIT_TAB_STATE_SAVING)  &&
 				  (state != GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW) &&
 				  (state != GEDIT_TAB_STATE_PRINTING) &&
-				  (state != GEDIT_TAB_STATE_PRINT_PREVIEWING) &&
 				  (state != GEDIT_TAB_STATE_SAVING_ERROR));
 }
 
@@ -174,8 +154,8 @@ sync_state (GeditTab      *tab,
 
 	state = gedit_tab_get_state (tab);
 
-	if ((state == GEDIT_TAB_STATE_LOADING)   ||
-	    (state == GEDIT_TAB_STATE_SAVING)    ||
+	if ((state == GEDIT_TAB_STATE_LOADING) ||
+	    (state == GEDIT_TAB_STATE_SAVING) ||
 	    (state == GEDIT_TAB_STATE_REVERTING))
 	{
 		gtk_widget_hide (tab_label->icon);
@@ -208,7 +188,7 @@ sync_state (GeditTab      *tab,
 	}
 
 	/* sync tip since encoding is known only after load/save end */
-	sync_tip (tab, tab_label);
+	sync_tooltip (tab, tab_label);
 }
 
 static void
@@ -216,7 +196,7 @@ gedit_tab_label_constructed (GObject *object)
 {
 	GeditTabLabel *tab_label = GEDIT_TAB_LABEL (object);
 
-	if (!tab_label->tab)
+	if (tab_label->tab == NULL)
 	{
 		g_critical ("The tab label was not properly constructed");
 		return;
@@ -251,7 +231,6 @@ gedit_tab_label_class_init (GeditTabLabelClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	object_class->finalize = gedit_tab_label_finalize;
 	object_class->set_property = gedit_tab_label_set_property;
 	object_class->get_property = gedit_tab_label_get_property;
 	object_class->constructed = gedit_tab_label_constructed;
@@ -278,16 +257,14 @@ gedit_tab_label_class_init (GeditTabLabelClass *klass)
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-tab-label.ui");
 	gtk_widget_class_bind_template_child (widget_class, GeditTabLabel, spinner);
-	gtk_widget_class_bind_template_child (widget_class, GeditTabLabel, close_button);
 	gtk_widget_class_bind_template_child (widget_class, GeditTabLabel, icon);
 	gtk_widget_class_bind_template_child (widget_class, GeditTabLabel, label);
+	gtk_widget_class_bind_template_child (widget_class, GeditTabLabel, close_button);
 }
 
 static void
 gedit_tab_label_init (GeditTabLabel *tab_label)
 {
-	tab_label->close_button_sensitive = TRUE;
-
 	gtk_widget_init_template (GTK_WIDGET (tab_label));
 
 	g_signal_connect (tab_label->close_button,
@@ -296,21 +273,6 @@ gedit_tab_label_init (GeditTabLabel *tab_label)
 	                  tab_label);
 }
 
-void
-gedit_tab_label_set_close_button_sensitive (GeditTabLabel *tab_label,
-					    gboolean       sensitive)
-{
-	g_return_if_fail (GEDIT_IS_TAB_LABEL (tab_label));
-
-	sensitive = (sensitive != FALSE);
-
-	if (tab_label->close_button_sensitive != sensitive)
-	{
-		tab_label->close_button_sensitive = sensitive;
-		update_close_button_sensitivity (tab_label);
-	}
-}
-
 GeditTab *
 gedit_tab_label_get_tab (GeditTabLabel *tab_label)
 {
@@ -322,13 +284,9 @@ gedit_tab_label_get_tab (GeditTabLabel *tab_label)
 GtkWidget *
 gedit_tab_label_new (GeditTab *tab)
 {
-	GeditTabLabel *tab_label;
-
-	tab_label = g_object_new (GEDIT_TYPE_TAB_LABEL,
-				  "tab", tab,
-				  NULL);
-
-	return GTK_WIDGET (tab_label);
+	return g_object_new (GEDIT_TYPE_TAB_LABEL,
+			     "tab", tab,
+			     NULL);
 }
 
 /* ex:set ts=8 noet: */
