@@ -51,7 +51,7 @@ struct _GeditTab
 
 	GeditTabState state;
 
-	GSettings *editor;
+	GSettings *editor_settings;
 
 	GeditViewFrame *frame;
 
@@ -61,7 +61,6 @@ struct _GeditTab
 	GeditPrintJob *print_job;
 	GtkWidget *print_preview;
 
-	GTask *task_saver;
 	GtkSourceFileSaverFlags save_flags;
 
 	/* tmp data for loading */
@@ -76,10 +75,10 @@ struct _GeditTab
 	gint auto_save_interval;
 	guint auto_save_timeout;
 
-	gint editable : 1;
-	gint auto_save : 1;
+	guint editable : 1;
+	guint auto_save : 1;
 
-	gint ask_if_externally_modified : 1;
+	guint ask_if_externally_modified : 1;
 
 	/* tmp data for loading */
 	guint user_requested_encoding : 1;
@@ -134,12 +133,12 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 static gboolean gedit_tab_auto_save (GeditTab *tab);
 
-static void load (GeditTab                *tab,
-		  const GtkSourceEncoding *encoding,
-		  gint                     line_pos,
-		  gint                     column_pos);
+static void launch_loader (GeditTab                *tab,
+			   const GtkSourceEncoding *encoding,
+			   gint                     line_pos,
+			   gint                     column_pos);
 
-static void save (GeditTab *tab);
+static void launch_saver (GTask *saving_task);
 
 static SaverData *
 saver_data_new (void)
@@ -161,6 +160,23 @@ saver_data_free (SaverData *data)
 	}
 }
 
+static void
+set_editable (GeditTab *tab,
+	      gboolean  editable)
+{
+	GeditView *view;
+	gboolean val;
+
+	tab->editable = editable != FALSE;
+
+	view = gedit_tab_get_view (tab);
+
+	val = (tab->state == GEDIT_TAB_STATE_NORMAL &&
+	       tab->editable);
+
+	gtk_text_view_set_editable (GTK_TEXT_VIEW (view), val);
+}
+
 static void
 install_auto_save_timeout (GeditTab *tab)
 {
@@ -190,15 +206,17 @@ static void
 update_auto_save_timeout (GeditTab *tab)
 {
 	GeditDocument *doc;
+	GtkSourceFile *file;
 
 	gedit_debug (DEBUG_TAB);
 
 	doc = gedit_tab_get_document (tab);
+	file = gedit_document_get_file (doc);
 
 	if (tab->state == GEDIT_TAB_STATE_NORMAL &&
 	    tab->auto_save &&
 	    !gedit_document_is_untitled (doc) &&
-	    !gedit_document_get_readonly (doc))
+	    !gtk_source_file_is_readonly (file))
 	{
 		install_auto_save_timeout (tab);
 	}
@@ -280,10 +298,9 @@ gedit_tab_dispose (GObject *object)
 {
 	GeditTab *tab = GEDIT_TAB (object);
 
-	g_clear_object (&tab->editor);
+	g_clear_object (&tab->editor_settings);
 	g_clear_object (&tab->print_job);
 	g_clear_object (&tab->print_preview);
-	g_clear_object (&tab->task_saver);
 
 	clear_loading (tab);
 
@@ -439,7 +456,6 @@ set_cursor_according_to_state (GtkTextView   *view,
 	    (state == GEDIT_TAB_STATE_REVERTING)        ||
 	    (state == GEDIT_TAB_STATE_SAVING)           ||
 	    (state == GEDIT_TAB_STATE_PRINTING)         ||
-	    (state == GEDIT_TAB_STATE_PRINT_PREVIEWING) ||
 	    (state == GEDIT_TAB_STATE_CLOSING))
 	{
 		cursor = gdk_cursor_new_for_display (
@@ -483,7 +499,7 @@ set_view_properties_according_to_state (GeditTab      *tab,
 	gboolean val;
 	gboolean hl_current_line;
 
-	hl_current_line = g_settings_get_boolean (tab->editor,
+	hl_current_line = g_settings_get_boolean (tab->editor_settings,
 						  GEDIT_SETTINGS_HIGHLIGHT_CURRENT_LINE);
 
 	view = gedit_tab_get_view (tab);
@@ -517,12 +533,15 @@ gedit_tab_set_state (GeditTab      *tab,
 
 	set_view_properties_according_to_state (tab, state);
 
-	if ((state == GEDIT_TAB_STATE_LOADING_ERROR) || /* FIXME: add other states if needed */
-	    (state == GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW))
+	/* Hide or show the document.
+	 * For GEDIT_TAB_STATE_LOADING_ERROR, tab->frame is either shown or
+	 * hidden, depending on the error.
+	 */
+	if (state == GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW)
 	{
 		gtk_widget_hide (GTK_WIDGET (tab->frame));
 	}
-	else if (tab->print_preview == NULL)
+	else if (state != GEDIT_TAB_STATE_LOADING_ERROR)
 	{
 		gtk_widget_show (GTK_WIDGET (tab->frame));
 	}
@@ -635,14 +654,11 @@ io_loading_error_info_bar_response (GtkWidget *info_bar,
 				    gint       response_id,
 				    GeditTab  *tab)
 {
-	GeditView *view;
 	GFile *location;
 	const GtkSourceEncoding *encoding;
 
 	g_return_if_fail (tab->loader != NULL);
 
-	view = gedit_tab_get_view (tab);
-
 	location = gtk_source_file_loader_get_location (tab->loader);
 
 	switch (response_id)
@@ -653,17 +669,17 @@ io_loading_error_info_bar_response (GtkWidget *info_bar,
 			set_info_bar (tab, NULL, GTK_RESPONSE_NONE);
 			gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING);
 
-			load (tab,
-			      encoding,
-			      tab->tmp_line_pos,
-			      tab->tmp_column_pos);
+			launch_loader (tab,
+				       encoding,
+				       tab->tmp_line_pos,
+				       tab->tmp_column_pos);
 			break;
 
 		case GTK_RESPONSE_YES:
 			/* This means that we want to edit the document anyway */
-			tab->editable = TRUE;
-			gtk_text_view_set_editable (GTK_TEXT_VIEW (view), TRUE);
+			set_editable (tab, TRUE);
 			set_info_bar (tab, NULL, GTK_RESPONSE_NONE);
+			gedit_tab_set_state (tab, GEDIT_TAB_STATE_NORMAL);
 			clear_loading (tab);
 			break;
 
@@ -687,8 +703,7 @@ file_already_open_warning_info_bar_response (GtkWidget *info_bar,
 
 	if (response_id == GTK_RESPONSE_YES)
 	{
-		tab->editable = TRUE;
-		gtk_text_view_set_editable (GTK_TEXT_VIEW (view), TRUE);
+		set_editable (tab, TRUE);
 	}
 
 	set_info_bar (tab, NULL, GTK_RESPONSE_NONE);
@@ -839,8 +854,9 @@ show_loading_info_bar (GeditTab *tab)
 }
 
 static void
-show_saving_info_bar (GeditTab *tab)
+show_saving_info_bar (GTask *saving_task)
 {
+	GeditTab *tab = g_task_get_source_object (saving_task);
 	GtkWidget *bar;
 	GeditDocument *doc;
 	gchar *short_name;
@@ -851,8 +867,6 @@ show_saving_info_bar (GeditTab *tab)
 	gchar *msg = NULL;
 	gint len;
 
-	g_return_if_fail (tab->task_saver != NULL);
-
 	if (tab->info_bar != NULL)
 	{
 		return;
@@ -880,7 +894,7 @@ show_saving_info_bar (GeditTab *tab)
 		SaverData *data;
 		GFile *location;
 
-		data = g_task_get_task_data (tab->task_saver);
+		data = g_task_get_task_data (saving_task);
 		location = gtk_source_file_saver_get_location (data->saver);
 
 		from = short_name;
@@ -1013,32 +1027,32 @@ scroll_to_cursor (GeditTab *tab)
 static void
 unrecoverable_saving_error_info_bar_response (GtkWidget *info_bar,
 					      gint       response_id,
-					      GeditTab  *tab)
+					      GTask     *saving_task)
 {
+	GeditTab *tab = g_task_get_source_object (saving_task);
 	GeditView *view;
 
 	gedit_tab_set_state (tab, GEDIT_TAB_STATE_NORMAL);
 
 	set_info_bar (tab, NULL, GTK_RESPONSE_NONE);
 
-	g_return_if_fail (tab->task_saver != NULL);
-	g_task_return_boolean (tab->task_saver, FALSE);
-
 	view = gedit_tab_get_view (tab);
 	gtk_widget_grab_focus (GTK_WIDGET (view));
+
+	g_task_return_boolean (saving_task, FALSE);
+	g_object_unref (saving_task);
 }
 
 /* Sets the save flags after an info bar response. */
 static void
-response_set_save_flags (GeditTab                *tab,
+response_set_save_flags (GTask                   *saving_task,
 			 GtkSourceFileSaverFlags  save_flags)
 {
-	SaverData *data;
+	GeditTab *tab = g_task_get_source_object (saving_task);
+	SaverData *data = g_task_get_task_data (saving_task);
 	gboolean create_backup;
 
-	data = g_task_get_task_data (tab->task_saver);
-
-	create_backup = g_settings_get_boolean (tab->editor,
+	create_backup = g_settings_get_boolean (tab->editor_settings,
 						GEDIT_SETTINGS_CREATE_BACKUP_COPY);
 
 	/* If we are here, it means that the user expressed his or her willing
@@ -1060,118 +1074,110 @@ response_set_save_flags (GeditTab                *tab,
 
 static void
 invalid_character_info_bar_response (GtkWidget *info_bar,
-                                     gint       response_id,
-                                     GeditTab  *tab)
+				     gint       response_id,
+				     GTask     *saving_task)
 {
 	if (response_id == GTK_RESPONSE_YES)
 	{
-		SaverData *data;
+		GeditTab *tab = g_task_get_source_object (saving_task);
+		SaverData *data = g_task_get_task_data (saving_task);
 		GtkSourceFileSaverFlags save_flags;
 
 		set_info_bar (tab, NULL, GTK_RESPONSE_NONE);
 
-		g_return_if_fail (tab->task_saver != NULL);
-		data = g_task_get_task_data (tab->task_saver);
-
 		/* Don't bug the user again with this... */
 		tab->save_flags |= GTK_SOURCE_FILE_SAVER_FLAGS_IGNORE_INVALID_CHARS;
 
 		save_flags = gtk_source_file_saver_get_flags (data->saver);
 		save_flags |= GTK_SOURCE_FILE_SAVER_FLAGS_IGNORE_INVALID_CHARS;
-		response_set_save_flags (tab, save_flags);
+		response_set_save_flags (saving_task, save_flags);
 
 		/* Force saving */
-		save (tab);
+		launch_saver (saving_task);
 	}
 	else
 	{
-		unrecoverable_saving_error_info_bar_response (info_bar, response_id, tab);
+		unrecoverable_saving_error_info_bar_response (info_bar, response_id, saving_task);
 	}
 }
 
 static void
 no_backup_error_info_bar_response (GtkWidget *info_bar,
 				   gint       response_id,
-				   GeditTab  *tab)
+				   GTask     *saving_task)
 {
 	if (response_id == GTK_RESPONSE_YES)
 	{
-		SaverData *data;
+		GeditTab *tab = g_task_get_source_object (saving_task);
+		SaverData *data = g_task_get_task_data (saving_task);
 		GtkSourceFileSaverFlags save_flags;
 
 		set_info_bar (tab, NULL, GTK_RESPONSE_NONE);
 
-		g_return_if_fail (tab->task_saver != NULL);
-		data = g_task_get_task_data (tab->task_saver);
-
 		data->force_no_backup = TRUE;
 		save_flags = gtk_source_file_saver_get_flags (data->saver);
-		response_set_save_flags (tab, save_flags);
+		response_set_save_flags (saving_task, save_flags);
 
 		/* Force saving */
-		save (tab);
+		launch_saver (saving_task);
 	}
 	else
 	{
-		unrecoverable_saving_error_info_bar_response (info_bar, response_id, tab);
+		unrecoverable_saving_error_info_bar_response (info_bar, response_id, saving_task);
 	}
 }
 
 static void
 externally_modified_error_info_bar_response (GtkWidget *info_bar,
 					     gint       response_id,
-					     GeditTab  *tab)
+					     GTask     *saving_task)
 {
 	if (response_id == GTK_RESPONSE_YES)
 	{
-		SaverData *data;
+		GeditTab *tab = g_task_get_source_object (saving_task);
+		SaverData *data = g_task_get_task_data (saving_task);
 		GtkSourceFileSaverFlags save_flags;
 
 		set_info_bar (tab, NULL, GTK_RESPONSE_NONE);
 
-		g_return_if_fail (tab->task_saver != NULL);
-		data = g_task_get_task_data (tab->task_saver);
-
 		/* ignore_modification_time should not be persisted in save
-		 * flags across saves (i.e. save_flags is not modified).
+		 * flags across saves (i.e. tab->save_flags is not modified).
 		 */
 		save_flags = gtk_source_file_saver_get_flags (data->saver);
 		save_flags |= GTK_SOURCE_FILE_SAVER_FLAGS_IGNORE_MODIFICATION_TIME;
-		response_set_save_flags (tab, save_flags);
+		response_set_save_flags (saving_task, save_flags);
 
 		/* Force saving */
-		save (tab);
+		launch_saver (saving_task);
 	}
 	else
 	{
-		unrecoverable_saving_error_info_bar_response (info_bar, response_id, tab);
+		unrecoverable_saving_error_info_bar_response (info_bar, response_id, saving_task);
 	}
 }
 
 static void
 recoverable_saving_error_info_bar_response (GtkWidget *info_bar,
 					    gint       response_id,
-					    GeditTab  *tab)
+					    GTask     *saving_task)
 {
 	if (response_id == GTK_RESPONSE_OK)
 	{
-		SaverData *data;
+		GeditTab *tab = g_task_get_source_object (saving_task);
+		SaverData *data = g_task_get_task_data (saving_task);
 		const GtkSourceEncoding *encoding;
 
 		set_info_bar (tab, NULL, GTK_RESPONSE_NONE);
 
-		g_return_if_fail (tab->task_saver != NULL);
-		data = g_task_get_task_data (tab->task_saver);
-
 		encoding = gedit_conversion_error_info_bar_get_encoding (GTK_WIDGET (info_bar));
 		g_return_if_fail (encoding != NULL);
 
 		gtk_source_file_saver_set_encoding (data->saver, encoding);
-		save (tab);
+		launch_saver (saving_task);
 	}
 	else
 	{
-		unrecoverable_saving_error_info_bar_response (info_bar, response_id, tab);
+		unrecoverable_saving_error_info_bar_response (info_bar, response_id, saving_task);
 	}
 }
 
@@ -1234,6 +1240,7 @@ view_focused_in (GtkWidget     *widget,
                  GeditTab      *tab)
 {
 	GeditDocument *doc;
+	GtkSourceFile *file;
 
 	g_return_val_if_fail (GEDIT_IS_TAB (tab), GDK_EVENT_PROPAGATE);
 
@@ -1250,18 +1257,19 @@ view_focused_in (GtkWidget     *widget,
 	}
 
 	doc = gedit_tab_get_document (tab);
+	file = gedit_document_get_file (doc);
 
 	/* If file was never saved or is remote we do not check */
-	if (!gedit_document_is_local (doc))
+	if (gtk_source_file_is_local (file))
 	{
-		return GDK_EVENT_PROPAGATE;
-	}
+		gtk_source_file_check_file_on_disk (file);
 
-	if (_gedit_document_check_externally_modified (doc))
-	{
-		gedit_tab_set_state (tab, GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION);
+		if (gtk_source_file_is_externally_modified (file))
+		{
+			gedit_tab_set_state (tab, GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION);
 
-		display_externally_modified_notification (tab);
+			display_externally_modified_notification (tab);
+		}
 	}
 
 	return GDK_EVENT_PROPAGATE;
@@ -1300,7 +1308,7 @@ _gedit_tab_set_network_available (GeditTab *tab,
 	file = gedit_document_get_file (doc);
 	location = gtk_source_file_get_location (file);
 
-	if (gedit_document_is_local (doc) || location == NULL)
+	if (gtk_source_file_is_local (file) || location == NULL)
 	{
 		return;
 	}
@@ -1335,7 +1343,7 @@ gedit_tab_init (GeditTab *tab)
 
 	tab->state = GEDIT_TAB_STATE_NORMAL;
 
-	tab->editor = g_settings_new ("org.gnome.gedit.preferences.editor");
+	tab->editor_settings = g_settings_new ("org.gnome.gedit.preferences.editor");
 
 	tab->editable = TRUE;
 
@@ -1345,9 +1353,9 @@ gedit_tab_init (GeditTab *tab)
 	                                GTK_ORIENTATION_VERTICAL);
 
 	/* Manage auto save data */
-	auto_save = g_settings_get_boolean (tab->editor,
+	auto_save = g_settings_get_boolean (tab->editor_settings,
 					    GEDIT_SETTINGS_AUTO_SAVE);
-	g_settings_get (tab->editor, GEDIT_SETTINGS_AUTO_SAVE_INTERVAL,
+	g_settings_get (tab->editor_settings, GEDIT_SETTINGS_AUTO_SAVE_INTERVAL,
 			"u", &auto_save_interval);
 
 	app = GEDIT_APP (g_application_get_default ());
@@ -1512,17 +1520,6 @@ _gedit_tab_get_name (GeditTab *tab)
 	}
 	else
 	{
- #if 0
-		if (gedit_document_get_readonly (doc))
-		{
-			tab_name = g_strdup_printf ("%s [%s]", docname,
-						/*Read only*/ _("RO"));
-		}
-		else
-		{
-			tab_name = g_strdup_printf ("%s", docname);
-		}
-#endif
 		tab_name = g_strdup (docname);
 	}
 
@@ -1634,7 +1631,6 @@ _gedit_tab_get_icon (GeditTab *tab)
 			icon_name = "printer-printing-symbolic";
 			break;
 
-		case GEDIT_TAB_STATE_PRINT_PREVIEWING:
 		case GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW:
 			icon_name = "printer-symbolic";
 			break;
@@ -1719,7 +1715,7 @@ goto_line (GeditTab *tab)
 	}
 
 	/* If enabled, move to the position stored in the metadata. */
-	if (g_settings_get_boolean (tab->editor, GEDIT_SETTINGS_RESTORE_CURSOR_POSITION))
+	if (g_settings_get_boolean (tab->editor_settings, GEDIT_SETTINGS_RESTORE_CURSOR_POSITION))
 	{
 		gchar *pos;
 		gint offset;
@@ -1751,6 +1747,114 @@ goto_line (GeditTab *tab)
 	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
 }
 
+static gboolean
+file_already_opened (GeditDocument *doc,
+		     GFile         *location)
+{
+	GList *all_documents;
+	GList *l;
+	gboolean already_opened = FALSE;
+
+	if (location == NULL)
+	{
+		return FALSE;
+	}
+
+	all_documents = gedit_app_get_documents (GEDIT_APP (g_application_get_default ()));
+
+	for (l = all_documents; l != NULL; l = l->next)
+	{
+		GeditDocument *cur_doc = l->data;
+		GtkSourceFile *cur_file;
+		GFile *cur_location;
+
+		if (cur_doc == doc)
+		{
+			continue;
+		}
+
+		cur_file = gedit_document_get_file (cur_doc);
+		cur_location = gtk_source_file_get_location (cur_file);
+
+		if (cur_location != NULL &&
+		    g_file_equal (location, cur_location))
+		{
+			already_opened = TRUE;
+			break;
+		}
+	}
+
+	g_list_free (all_documents);
+
+	return already_opened;
+}
+
+static void
+successful_load (GeditTab *tab)
+{
+	GeditDocument *doc;
+	GtkSourceFile *file;
+	GFile *location;
+
+	doc = gedit_tab_get_document (tab);
+	file = gedit_document_get_file (doc);
+
+	if (tab->user_requested_encoding)
+	{
+		const GtkSourceEncoding *encoding = gtk_source_file_loader_get_encoding (tab->loader);
+		const gchar *charset = gtk_source_encoding_get_charset (encoding);
+
+		gedit_document_set_metadata (doc,
+					     GEDIT_METADATA_ATTRIBUTE_ENCODING, charset,
+					     NULL);
+	}
+
+	goto_line (tab);
+
+	/* Scroll to the cursor when the document is loaded, we need to do it in
+	 * an idle as after the document is loaded the textview is still
+	 * redrawing and relocating its internals.
+	 */
+	if (tab->idle_scroll == 0)
+	{
+		tab->idle_scroll = g_idle_add ((GSourceFunc)scroll_to_cursor, tab);
+	}
+
+	location = gtk_source_file_loader_get_location (tab->loader);
+
+	/* If the document is readonly we don't care how many times the file
+	 * is opened.
+	 */
+	if (!gtk_source_file_is_readonly (file) &&
+	    file_already_opened (doc, location))
+	{
+		GtkWidget *info_bar;
+
+		set_editable (tab, FALSE);
+
+		info_bar = gedit_file_already_open_warning_info_bar_new (location);
+
+		g_signal_connect (info_bar,
+				  "response",
+				  G_CALLBACK (file_already_open_warning_info_bar_response),
+				  tab);
+
+		set_info_bar (tab, info_bar, GTK_RESPONSE_CANCEL);
+	}
+
+	/* When loading from stdin, the contents may not be saved, so set the
+	 * buffer as modified.
+	 */
+	if (location == NULL)
+	{
+		gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (doc), TRUE);
+	}
+
+	tab->ask_if_externally_modified = TRUE;
+
+	g_signal_emit_by_name (doc, "loaded");
+}
+
 static void
 load_cb (GtkSourceFileLoader *loader,
 	 GAsyncResult        *result,
@@ -1779,29 +1883,9 @@ load_cb (GtkSourceFileLoader *loader,
 
 	set_info_bar (tab, NULL, GTK_RESPONSE_NONE);
 
-	/* Load was successful. */
-	if (error == NULL ||
-	    (error->domain == GTK_SOURCE_FILE_LOADER_ERROR &&
-	     error->code == GTK_SOURCE_FILE_LOADER_ERROR_CONVERSION_FALLBACK))
-	{
-		if (tab->user_requested_encoding)
-		{
-			const GtkSourceEncoding *encoding = gtk_source_file_loader_get_encoding (loader);
-			const gchar *charset = gtk_source_encoding_get_charset (encoding);
-
-			gedit_document_set_metadata (doc,
-						     GEDIT_METADATA_ATTRIBUTE_ENCODING, charset,
-						     NULL);
-		}
-
-		goto_line (tab);
-	}
-
 	/* Special case creating a named new doc. */
 	create_named_new_doc = (_gedit_document_get_create (doc) &&
-				error != NULL &&
-				error->domain == G_IO_ERROR &&
-				error->code == G_IO_ERROR_NOT_FOUND &&
+				g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND) &&
 				g_file_has_uri_scheme (location, "file"));
 
 	if (create_named_new_doc)
@@ -1810,73 +1894,15 @@ load_cb (GtkSourceFileLoader *loader,
 		error = NULL;
 	}
 
-	/* If the error is CONVERSION FALLBACK don't treat it as a normal error. */
-	if (error != NULL &&
-	    (error->domain != GTK_SOURCE_FILE_LOADER_ERROR ||
-	     error->code != GTK_SOURCE_FILE_LOADER_ERROR_CONVERSION_FALLBACK))
+	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
 	{
-		if (tab->state == GEDIT_TAB_STATE_LOADING)
-		{
-			gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING_ERROR);
-		}
-		else
-		{
-			gedit_tab_set_state (tab, GEDIT_TAB_STATE_REVERTING_ERROR);
-		}
-
-		if (error->domain == G_IO_ERROR &&
-		    error->code == G_IO_ERROR_CANCELLED)
-		{
-			remove_tab (tab);
-		}
-		else
-		{
-			GtkWidget *info_bar;
-
-			if (location != NULL)
-			{
-				gedit_recent_remove_if_local (location);
-			}
-
-			if (tab->state == GEDIT_TAB_STATE_LOADING_ERROR)
-			{
-				const GtkSourceEncoding *encoding;
-
-				encoding = gtk_source_file_loader_get_encoding (loader);
-
-				info_bar = gedit_io_loading_error_info_bar_new (location, encoding, error);
-
-				g_signal_connect (info_bar,
-						  "response",
-						  G_CALLBACK (io_loading_error_info_bar_response),
-						  tab);
-			}
-			else
-			{
-				g_return_if_fail (tab->state == GEDIT_TAB_STATE_REVERTING_ERROR);
-
-				info_bar = gedit_unrecoverable_reverting_error_info_bar_new (location, error);
-
-				g_signal_connect (info_bar,
-						  "response",
-						  G_CALLBACK (unrecoverable_reverting_error_info_bar_response),
-						  tab);
-			}
-
-			set_info_bar (tab, info_bar, GTK_RESPONSE_CANCEL);
-		}
-
+		remove_tab (tab);
 		goto end;
 	}
 
-	if (!create_named_new_doc)
-	{
-		gedit_recent_add_document (doc);
-	}
-
-	if (error != NULL &&
-	    error->domain == GTK_SOURCE_FILE_LOADER_ERROR &&
-	    error->code == GTK_SOURCE_FILE_LOADER_ERROR_CONVERSION_FALLBACK)
+	if (g_error_matches (error,
+			     GTK_SOURCE_FILE_LOADER_ERROR,
+			     GTK_SOURCE_FILE_LOADER_ERROR_CONVERSION_FALLBACK))
 	{
 		GtkWidget *info_bar;
 		const GtkSourceEncoding *encoding;
@@ -1884,7 +1910,7 @@ load_cb (GtkSourceFileLoader *loader,
 		/* Set the tab as not editable as we have an error, the user can
 		 * decide to make it editable again.
 		 */
-		tab->editable = FALSE;
+		set_editable (tab, FALSE);
 
 		encoding = gtk_source_file_loader_get_encoding (loader);
 
@@ -1896,76 +1922,84 @@ load_cb (GtkSourceFileLoader *loader,
 				  tab);
 
 		set_info_bar (tab, info_bar, GTK_RESPONSE_CANCEL);
-	}
 
-	/* Scroll to the cursor when the document is loaded, we need to do it in
-	 * an idle as after the document is loaded the textview is still
-	 * redrawing and relocating its internals.
-	 */
-	if (tab->idle_scroll == 0)
-	{
-		tab->idle_scroll = g_idle_add ((GSourceFunc)scroll_to_cursor, tab);
-	}
-
-	/* If the document is readonly we don't care how many times the document
-	 * is opened.
-	 */
-	if (!gedit_document_get_readonly (doc))
-	{
-		GList *all_documents;
-		GList *l;
-
-		all_documents = gedit_app_get_documents (GEDIT_APP (g_application_get_default ()));
-
-		for (l = all_documents; l != NULL; l = g_list_next (l))
+		if (tab->state == GEDIT_TAB_STATE_LOADING)
 		{
-			GeditDocument *cur_doc = l->data;
-
-			if (cur_doc != doc)
-			{
-				GtkSourceFile *cur_file = gedit_document_get_file (cur_doc);
-				GFile *cur_location = gtk_source_file_get_location (cur_file);
-
-				if (cur_location != NULL && location != NULL &&
-				    g_file_equal (location, cur_location))
-				{
-					GtkWidget *info_bar;
-
-					tab->editable = FALSE;
-
-					info_bar = gedit_file_already_open_warning_info_bar_new (location);
-
-					g_signal_connect (info_bar,
-							  "response",
-							  G_CALLBACK (file_already_open_warning_info_bar_response),
-							  tab);
-
-					set_info_bar (tab, info_bar, GTK_RESPONSE_CANCEL);
-
-					break;
-				}
-			}
+			gtk_widget_show (GTK_WIDGET (tab->frame));
+			gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING_ERROR);
+		}
+		else
+		{
+			gedit_tab_set_state (tab, GEDIT_TAB_STATE_REVERTING_ERROR);
 		}
 
-		g_list_free (all_documents);
+		/* The loading was successful, despite some invalid characters.
+		 * The document can be edited.
+		 */
+		successful_load (tab);
+		gedit_recent_add_document (doc);
+		goto end;
 	}
 
+	if (error != NULL)
+	{
+		GtkWidget *info_bar;
+
+		if (tab->state == GEDIT_TAB_STATE_LOADING)
+		{
+			gtk_widget_hide (GTK_WIDGET (tab->frame));
+			gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING_ERROR);
+		}
+		else
+		{
+			gedit_tab_set_state (tab, GEDIT_TAB_STATE_REVERTING_ERROR);
+		}
+
+		if (location != NULL)
+		{
+			gedit_recent_remove_if_local (location);
+		}
+
+		if (tab->state == GEDIT_TAB_STATE_LOADING_ERROR)
+		{
+			const GtkSourceEncoding *encoding;
+
+			encoding = gtk_source_file_loader_get_encoding (loader);
+
+			info_bar = gedit_io_loading_error_info_bar_new (location, encoding, error);
+
+			g_signal_connect (info_bar,
+					  "response",
+					  G_CALLBACK (io_loading_error_info_bar_response),
+					  tab);
+		}
+		else
+		{
+			g_return_if_fail (tab->state == GEDIT_TAB_STATE_REVERTING_ERROR);
+
+			info_bar = gedit_unrecoverable_reverting_error_info_bar_new (location, error);
+
+			g_signal_connect (info_bar,
+					  "response",
+					  G_CALLBACK (unrecoverable_reverting_error_info_bar_response),
+					  tab);
+		}
+
+		set_info_bar (tab, info_bar, GTK_RESPONSE_CANCEL);
+		goto end;
+	}
+
+	g_assert (error == NULL);
+
 	gedit_tab_set_state (tab, GEDIT_TAB_STATE_NORMAL);
+	successful_load (tab);
 
-	if (location == NULL)
+	if (!create_named_new_doc)
 	{
-		/* FIXME: hackish */
-		gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (doc), TRUE);
+		gedit_recent_add_document (doc);
 	}
 
-	tab->ask_if_externally_modified = TRUE;
-
-	if (error == NULL)
-	{
-		clear_loading (tab);
-	}
-
-	g_signal_emit_by_name (doc, "loaded");
+	clear_loading (tab);
 
 end:
 	/* Async operation finished. */
@@ -2024,10 +2058,10 @@ get_candidate_encodings (GeditTab *tab)
 }
 
 static void
-load (GeditTab                *tab,
-      const GtkSourceEncoding *encoding,
-      gint                     line_pos,
-      gint                     column_pos)
+launch_loader (GeditTab                *tab,
+	       const GtkSourceEncoding *encoding,
+	       gint                     line_pos,
+	       gint                     column_pos)
 {
 	GSList *candidate_encodings = NULL;
 	GeditDocument *doc;
@@ -2109,7 +2143,7 @@ _gedit_tab_load (GeditTab                *tab,
 
 	_gedit_document_set_create (doc, create);
 
-	load (tab, encoding, line_pos, column_pos);
+	launch_loader (tab, encoding, line_pos, column_pos);
 }
 
 void
@@ -2145,7 +2179,7 @@ _gedit_tab_load_stream (GeditTab                *tab,
 
 	_gedit_document_set_create (doc, FALSE);
 
-	load (tab, encoding, line_pos, column_pos);
+	launch_loader (tab, encoding, line_pos, column_pos);
 }
 
 void
@@ -2179,7 +2213,7 @@ _gedit_tab_revert (GeditTab *tab)
 
 	tab->loader = gtk_source_file_loader_new (GTK_SOURCE_BUFFER (doc), file);
 
-	load (tab, NULL, 0, 0);
+	launch_loader (tab, NULL, 0, 0);
 }
 
 static void
@@ -2200,15 +2234,17 @@ close_printing (GeditTab *tab)
 }
 
 static void
-saver_progress_cb (goffset   size,
-		   goffset   total_size,
-		   GeditTab *tab)
+saver_progress_cb (goffset  size,
+		   goffset  total_size,
+		   GTask   *saving_task)
 {
+	GeditTab *tab = g_task_get_source_object (saving_task);
+
 	g_return_if_fail (tab->state == GEDIT_TAB_STATE_SAVING);
 
 	if (should_show_progress_info (tab, size, total_size))
 	{
-		show_saving_info_bar (tab);
+		show_saving_info_bar (saving_task);
 		info_bar_set_progress (tab, size, total_size);
 	}
 }
@@ -2216,14 +2252,14 @@ saver_progress_cb (goffset   size,
 static void
 save_cb (GtkSourceFileSaver *saver,
 	 GAsyncResult       *result,
-	 GeditTab           *tab)
+	 GTask              *saving_task)
 {
+	GeditTab *tab = g_task_get_source_object (saving_task);
 	GeditDocument *doc = gedit_tab_get_document (tab);
 	GFile *location = gtk_source_file_saver_get_location (saver);
 	GError *error = NULL;
 
 	g_return_if_fail (tab->state == GEDIT_TAB_STATE_SAVING);
-	g_return_if_fail (tab->task_saver != NULL);
 
 	gtk_source_file_saver_save_finish (saver, result, &error);
 
@@ -2256,7 +2292,7 @@ save_cb (GtkSourceFileSaver *saver,
 			g_signal_connect (info_bar,
 					  "response",
 					  G_CALLBACK (externally_modified_error_info_bar_response),
-					  tab);
+					  saving_task);
 		}
 		else if (error->domain == G_IO_ERROR &&
 			 error->code == G_IO_ERROR_CANT_CREATE_BACKUP)
@@ -2268,7 +2304,7 @@ save_cb (GtkSourceFileSaver *saver,
 			g_signal_connect (info_bar,
 					  "response",
 					  G_CALLBACK (no_backup_error_info_bar_response),
-					  tab);
+					  saving_task);
 		}
 		else if (error->domain == GTK_SOURCE_FILE_SAVER_ERROR &&
 			 error->code == GTK_SOURCE_FILE_SAVER_ERROR_INVALID_CHARS)
@@ -2282,7 +2318,7 @@ save_cb (GtkSourceFileSaver *saver,
 			g_signal_connect (info_bar,
 			                  "response",
 			                  G_CALLBACK (invalid_character_info_bar_response),
-			                  tab);
+			                  saving_task);
 		}
 		else if (error->domain == GTK_SOURCE_FILE_SAVER_ERROR ||
 			 (error->domain == G_IO_ERROR &&
@@ -2298,7 +2334,7 @@ save_cb (GtkSourceFileSaver *saver,
 			g_signal_connect (info_bar,
 					  "response",
 					  G_CALLBACK (unrecoverable_saving_error_info_bar_response),
-					  tab);
+					  saving_task);
 		}
 		else
 		{
@@ -2316,7 +2352,7 @@ save_cb (GtkSourceFileSaver *saver,
 			g_signal_connect (info_bar,
 					  "response",
 					  G_CALLBACK (recoverable_saving_error_info_bar_response),
-					  tab);
+					  saving_task);
 		}
 
 		set_info_bar (tab, info_bar, GTK_RESPONSE_CANCEL);
@@ -2330,7 +2366,8 @@ save_cb (GtkSourceFileSaver *saver,
 		tab->ask_if_externally_modified = TRUE;
 
 		g_signal_emit_by_name (doc, "saved");
-		g_task_return_boolean (tab->task_saver, TRUE);
+		g_task_return_boolean (saving_task, TRUE);
+		g_object_unref (saving_task);
 	}
 
 	if (error != NULL)
@@ -2340,20 +2377,16 @@ save_cb (GtkSourceFileSaver *saver,
 }
 
 static void
-save (GeditTab *tab)
+launch_saver (GTask *saving_task)
 {
-	GeditDocument *doc;
-	SaverData *data;
-
-	g_return_if_fail (G_IS_TASK (tab->task_saver));
+	GeditTab *tab = g_task_get_source_object (saving_task);
+	GeditDocument *doc = gedit_tab_get_document (tab);
+	SaverData *data = g_task_get_task_data (saving_task);
 
 	gedit_tab_set_state (tab, GEDIT_TAB_STATE_SAVING);
 
-	doc = gedit_tab_get_document (tab);
 	g_signal_emit_by_name (doc, "save");
 
-	data = g_task_get_task_data (tab->task_saver);
-
 	if (tab->timer != NULL)
 	{
 		g_timer_destroy (tab->timer);
@@ -2363,12 +2396,12 @@ save (GeditTab *tab)
 
 	gtk_source_file_saver_save_async (data->saver,
 					  G_PRIORITY_DEFAULT,
-					  g_task_get_cancellable (tab->task_saver),
+					  g_task_get_cancellable (saving_task),
 					  (GFileProgressCallback) saver_progress_cb,
-					  tab,
+					  saving_task,
 					  NULL,
 					  (GAsyncReadyCallback) save_cb,
-					  tab);
+					  saving_task);
 }
 
 /* Gets the initial save flags, when launching a new FileSaver. */
@@ -2381,7 +2414,7 @@ get_initial_save_flags (GeditTab *tab,
 
 	save_flags = tab->save_flags;
 
-	create_backup = g_settings_get_boolean (tab->editor,
+	create_backup = g_settings_get_boolean (tab->editor_settings,
 						GEDIT_SETTINGS_CREATE_BACKUP_COPY);
 
 	/* In case of autosaving, we need to preserve the backup that was produced
@@ -2402,6 +2435,7 @@ _gedit_tab_save_async (GeditTab            *tab,
 		       GAsyncReadyCallback  callback,
 		       gpointer             user_data)
 {
+	GTask *saving_task;
 	SaverData *data;
 	GeditDocument *doc;
 	GtkSourceFile *file;
@@ -2412,12 +2446,6 @@ _gedit_tab_save_async (GeditTab            *tab,
 	                  tab->state == GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION ||
 	                  tab->state == GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW);
 
-	if (tab->task_saver != NULL)
-	{
-		g_warning ("GeditTab: file saver already exists.");
-		return;
-	}
-
 	/* The Save and Save As window actions are insensitive when the print
 	 * preview is shown, but it's still possible to save several documents
 	 * at once (with the Save All action or when quitting gedit). In that
@@ -2435,12 +2463,10 @@ _gedit_tab_save_async (GeditTab            *tab,
 	doc = gedit_tab_get_document (tab);
 	g_return_if_fail (!gedit_document_is_untitled (doc));
 
-	tab->task_saver = g_task_new (tab, cancellable, callback, user_data);
+	saving_task = g_task_new (tab, cancellable, callback, user_data);
 
 	data = saver_data_new ();
-	g_task_set_task_data (tab->task_saver,
-			      data,
-			      (GDestroyNotify) saver_data_free);
+	g_task_set_task_data (saving_task, data, (GDestroyNotify) saver_data_free);
 
 	save_flags = get_initial_save_flags (tab, FALSE);
 
@@ -2459,22 +2485,16 @@ _gedit_tab_save_async (GeditTab            *tab,
 
 	gtk_source_file_saver_set_flags (data->saver, save_flags);
 
-	save (tab);
+	launch_saver (saving_task);
 }
 
 gboolean
 _gedit_tab_save_finish (GeditTab     *tab,
 			GAsyncResult *result)
 {
-	gboolean success;
-
 	g_return_val_if_fail (g_task_is_valid (result, tab), FALSE);
-	g_return_val_if_fail (tab->task_saver == G_TASK (result), FALSE);
 
-	success = g_task_propagate_boolean (tab->task_saver, NULL);
-	g_clear_object (&tab->task_saver);
-
-	return success;
+	return g_task_propagate_boolean (G_TASK (result), NULL);
 }
 
 static void
@@ -2488,6 +2508,7 @@ auto_save_finished_cb (GeditTab     *tab,
 static gboolean
 gedit_tab_auto_save (GeditTab *tab)
 {
+	GTask *saving_task;
 	SaverData *data;
 	GeditDocument *doc;
 	GtkSourceFile *file;
@@ -2496,8 +2517,10 @@ gedit_tab_auto_save (GeditTab *tab)
 	gedit_debug (DEBUG_TAB);
 
 	doc = gedit_tab_get_document (tab);
+	file = gedit_document_get_file (doc);
+
 	g_return_val_if_fail (!gedit_document_is_untitled (doc), G_SOURCE_REMOVE);
-	g_return_val_if_fail (!gedit_document_get_readonly (doc), G_SOURCE_REMOVE);
+	g_return_val_if_fail (!gtk_source_file_is_readonly (file), G_SOURCE_REMOVE);
 
 	if (!gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc)))
 	{
@@ -2521,30 +2544,20 @@ gedit_tab_auto_save (GeditTab *tab)
 	/* Set auto_save_timeout to 0 since the timeout is going to be destroyed */
 	tab->auto_save_timeout = 0;
 
-	if (tab->task_saver != NULL)
-	{
-		g_warning ("GeditTab: file saver already exists.");
-		return G_SOURCE_REMOVE;
-	}
-
-	tab->task_saver = g_task_new (tab,
-	                              NULL,
-	                              (GAsyncReadyCallback) auto_save_finished_cb,
-	                              NULL);
+	saving_task = g_task_new (tab,
+				  NULL,
+				  (GAsyncReadyCallback) auto_save_finished_cb,
+				  NULL);
 
 	data = saver_data_new ();
-	g_task_set_task_data (tab->task_saver,
-			      data,
-			      (GDestroyNotify) saver_data_free);
-
-	file = gedit_document_get_file (doc);
+	g_task_set_task_data (saving_task, data, (GDestroyNotify) saver_data_free);
 
 	data->saver = gtk_source_file_saver_new (GTK_SOURCE_BUFFER (doc), file);
 
 	save_flags = get_initial_save_flags (tab, TRUE);
 	gtk_source_file_saver_set_flags (data->saver, save_flags);
 
-	save (tab);
+	launch_saver (saving_task);
 
 	return G_SOURCE_REMOVE;
 }
@@ -2562,6 +2575,7 @@ _gedit_tab_save_as_async (GeditTab                 *tab,
 			  GAsyncReadyCallback       callback,
 			  gpointer                  user_data)
 {
+	GTask *saving_task;
 	SaverData *data;
 	GeditDocument *doc;
 	GtkSourceFile *file;
@@ -2574,24 +2588,16 @@ _gedit_tab_save_as_async (GeditTab                 *tab,
 	g_return_if_fail (G_IS_FILE (location));
 	g_return_if_fail (encoding != NULL);
 
-	if (tab->task_saver != NULL)
-	{
-		g_warning ("GeditTab: file saver already exists.");
-		return;
-	}
-
 	/* See note at _gedit_tab_save_async(). */
 	if (tab->state == GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW)
 	{
 		close_printing (tab);
 	}
 
-	tab->task_saver = g_task_new (tab, cancellable, callback, user_data);
+	saving_task = g_task_new (tab, cancellable, callback, user_data);
 
 	data = saver_data_new ();
-	g_task_set_task_data (tab->task_saver,
-			      data,
-			      (GDestroyNotify) saver_data_free);
+	g_task_set_task_data (saving_task, data, (GDestroyNotify) saver_data_free);
 
 	doc = gedit_tab_get_document (tab);
 
@@ -2620,7 +2626,7 @@ _gedit_tab_save_as_async (GeditTab                 *tab,
 	gtk_source_file_saver_set_compression_type (data->saver, compression_type);
 	gtk_source_file_saver_set_flags (data->saver, save_flags);
 
-	save (tab);
+	launch_saver (saving_task);
 }
 
 #define GEDIT_PAGE_SETUP_KEY "gedit-page-setup-key"
@@ -2747,8 +2753,7 @@ done_printing_cb (GeditPrintJob       *job,
 {
 	GeditView *view;
 
-	g_return_if_fail (tab->state == GEDIT_TAB_STATE_PRINT_PREVIEWING ||
-	                  tab->state == GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW ||
+	g_return_if_fail (tab->state == GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW ||
 	                  tab->state == GEDIT_TAB_STATE_PRINTING);
 
 	if (result == GEDIT_PRINT_JOB_RESULT_OK)
@@ -3044,10 +3049,10 @@ gedit_tab_set_info_bar (GeditTab  *tab,
 	set_info_bar (tab, info_bar, GTK_RESPONSE_NONE);
 }
 
-GtkWidget *
+GeditViewFrame *
 _gedit_tab_get_view_frame (GeditTab *tab)
 {
-	return GTK_WIDGET (tab->frame);
+	return tab->frame;
 }
 
 /* ex:set ts=8 noet: */
