@@ -26,7 +26,7 @@ from .shareddata import SharedData
 class AppActivatable(GObject.Object, Gedit.AppActivatable):
     __gtype_name__ = "GeditSnippetsAppActivatable"
 
-    app = GObject.property(type=Gedit.App)
+    app = GObject.Property(type=Gedit.App)
 
     def __init__(self):
         GObject.Object.__init__(self)
